==> haskell-http-date-0.0.8-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http-date.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-date
version: 0.0.8
id: http-date-0.0.8-LxW3a5AvFDi7Od6uxNY2LE
key: http-date-0.0.8-LxW3a5AvFDi7Od6uxNY2LE
license: BSD-3-Clause
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
author: Kazu Yamamoto <kazu@iij.ad.jp>
synopsis: HTTP Date parser/formatter
description:
    Fast parser and formatter for HTTP Date
category: Network, Web
abi: 3d5854211fbdae72ef3b348ec81720e6
exposed: True
exposed-modules:
    Network.HTTP.Date
hidden-modules: Network.HTTP.Date.Converter
                Network.HTTP.Date.Formatter Network.HTTP.Date.Types
                Network.HTTP.Date.Parser
import-dirs: /usr/lib/ghc-8.4.3/site-local/http-date-0.0.8
library-dirs: /usr/lib/ghc-8.4.3/site-local/http-date-0.0.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/http-date-0.0.8
hs-libraries: HShttp-date-0.0.8-LxW3a5AvFDi7Od6uxNY2LE
depends:
    base-4.11.1.0 array-0.5.2.0
    attoparsec-0.13.2.2-KQfUWPhYfGY7y53JEXSJuZ bytestring-0.10.8.2
    time-1.8.0.2
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             array-0.5.2.0=001d57bac323829c35f5e9edd158c1ef
             attoparsec-0.13.2.2-KQfUWPhYfGY7y53JEXSJuZ=5fc61cc528c94bde8145f6cbd8ed3b00
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             time-1.8.0.2=976962cc6498b843f1efb5bef740838e
haddock-interfaces: /usr/share/doc/haskell-http-date/html/http-date.haddock
haddock-html: /usr/share/doc/haskell-http-date/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-date-0.0.8-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http-date.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-date
version: 0.0.8
id: http-date-0.0.8-FDlKlTsioiz8AH5lqubOkX
key: http-date-0.0.8-FDlKlTsioiz8AH5lqubOkX
license: BSD-3-Clause
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
author: Kazu Yamamoto <kazu@iij.ad.jp>
synopsis: HTTP Date parser/formatter
description:
    Fast parser and formatter for HTTP Date
category: Network, Web
abi: 2ebaff320b195158e94f6f30f07e8c2a
exposed: True
exposed-modules:
    Network.HTTP.Date
hidden-modules: Network.HTTP.Date.Converter
                Network.HTTP.Date.Formatter Network.HTTP.Date.Types
                Network.HTTP.Date.Parser
import-dirs: /usr/lib/ghc-8.4.3/site-local/http-date-0.0.8
library-dirs: /usr/lib/ghc-8.4.3/site-local/http-date-0.0.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/http-date-0.0.8
hs-libraries: HShttp-date-0.0.8-FDlKlTsioiz8AH5lqubOkX
depends:
    base-4.11.1.0 array-0.5.2.0
    attoparsec-0.13.2.2-66ub406fEYL5HI27KdshEC bytestring-0.10.8.2
    time-1.8.0.2
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             array-0.5.2.0=001d57bac323829c35f5e9edd158c1ef
             attoparsec-0.13.2.2-66ub406fEYL5HI27KdshEC=c6a831664a8826b2c70f720ac226f7d1
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             time-1.8.0.2=976962cc6498b843f1efb5bef740838e
haddock-interfaces: /usr/share/doc/haskell-http-date/html/http-date.haddock
haddock-html: /usr/share/doc/haskell-http-date/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
